import React, { Component } from 'react';
import { Flex, NavBar, List, InputItem, Button, WhiteSpace, WingBlank, Toast } from 'antd-mobile';
import { Formik, Field, Form, withFormik } from 'formik';
import { http, api } from "@/utils";

const InnerForm = ({
    values,
    errors,
    touched,
    setFieldValue,
    handleBlur,
    handleSubmit,
    isSubmitting,
}) => (
        <form>
            <InputItem
                clear
                name="real_name"
                onChange={(value) => setFieldValue('real_name', value)}
                placeholder="请输入您的真实姓名"
                value={values.real_name}
            >姓名</InputItem>
            <InputItem
                clear
                type='phone'
                name='cellphone'
                placeholder="请输入您的手机号码"
                onChange={(value) => setFieldValue('cellphone', value)}
                value={values.cellphone}
            >电话</InputItem>
            <InputItem
                clear
                name='qq'
                placeholder="请输入您的QQ号码"
                maxLength='15'
                onChange={(value) => setFieldValue('qq', value)}
                value={values.qq}
            >QQ</InputItem>

            <div style={{ marginTop: '21px' }}>
                <WingBlank>
                    <Button type='primary' onClick={handleSubmit}>确认</Button>
                </WingBlank>
            </div>
        </form>
    );

const MyForm = withFormik({
    mapPropsToValues: props => ({ ...props.userInfo }),
    validate: (values, props) => {
        const errors = {};
        return errors;
    },
    handleSubmit: (
        values,
        FormBag
    ) => {
        if (!values.real_name) {
            Toast.info('请输入姓名！', undefined, undefined, false);
            return;
        }
        if (!values.cellphone) {
            Toast.info('请输入手机号！', undefined, undefined, false);
            return;
        } else if (!/1\d{10}/g.test(values.cellphone.replace(/\s+/g, ''))) {
            Toast.info('请输入正确的手机号！', undefined, undefined, false);
            return;
        }
        if (!values.qq) {
            Toast.info('请输入QQ号！', undefined, undefined, false);
            return;
        } else if (!/\d{5,}/g.test(values.qq)) {
            Toast.info('请输入正确QQ号！', undefined, undefined, false);
            return;
        }
        http.post(`${api.home}/m/order/saveUserInfo`, values).then(res=>{
            if(res.data.code !== 200) {
                Toast.info(res.data.msg, undefined, undefined, false);
                return;
            }
            Toast.info('保存成功！', undefined, undefined, false);
            FormBag.props.history.replace({
                pathname: '/order',
                state: values
            });
        });
    },
})(InnerForm);

class Orderinfo extends Component {
    constructor(props) {
        super(props);
    }

    render() {
        return (
            <div>
                <NavBar
                    style={{ "height": "44px", backgroundColor: '#F7F9FC' }}
                    className="order-tab"
                    mode="light"
                    icon={<i className="iconfont iconiconfront-68"></i>}
                >
                    报名信息
                    </NavBar>
                <MyForm history={this.props.history} userInfo={this.props.location.state}/>
            </div>
        )
    }

};

export default Orderinfo;